## Dataset Attribution
This dataset was created by Leon Yin, Davey Alba and Leonardo Nicoletti and is licensed under the Apache 2.0 license.

- Original Source: [github.com](https://github.com/BloombergGraphics/2024-openai-gpt-hiring-racial-discrimination/tree/main/data/input)
- License: [https://www.apache.org/licenses/LICENSE-2.0](https://www.apache.org/licenses/LICENSE-2.0)
- Changes Made: Names were extracted from the repository.